@@ -1,4 +1,3 @@
-
 # Exported Functions ------------------------------------------------------
 
 #' @title Vertex Attributes for Bipartite Network
@@ -19,14 +18,12 @@
 #' bipvals(nw, mode = 1, "male")
 #'
 bipvals <- function(nw, mode, val) {
-
   if (!is.numeric(nw$gal$bipartite)) {
     stop("nw must be a bipartite network", call. = FALSE)
   }
   if (missing(mode)) {
     stop("Specify mode=1 or mode=2", call. = FALSE)
   }
-
   nw %s% modeids(nw, mode) %v% val
 }
 
@@ -64,7 +61,7 @@ bipvals <- function(nw, mode, val) {
 #' # Calculate equilibrium for a DCM
 #' param <- param.dcm(inf.prob = 0.2, inf.prob.g2 = 0.1, act.rate = 0.5,
 #'                    balance = "g1", rec.rate = 1 / 50, rec.rate.g2 = 1 / 50,
-#'                    b.rate = 1 / 100, b.rate.g2 = NA, ds.rate = 1 / 100,
+#'                    a.rate = 1 / 100, a.rate.g2 = NA, ds.rate = 1 / 100,
 #'                    ds.rate.g2 = 1 / 100, di.rate = 1 / 90,
 #'                    di.rate.g2 = 1 / 90)
 #' init <- init.dcm(s.num = 500, i.num = 1,
@@ -82,15 +79,12 @@ bipvals <- function(nw, mode, val) {
 #'
 calc_eql <- function(x, numer = "i.num", denom = "num",
                      nsteps, threshold = 0.001, digits = 4, invisible = FALSE) {
-
   if (!(class(x) %in% c("dcm", "icm", "netsim"))) {
     stop("x must an object of class dcm, icm, or netsim", call. = FALSE)
   }
-
   # Change scipen based on digits
   old.scipen <- options()$scipen
   options(scipen = digits + 1)
-
   # Convert model to df and calculate prevalence
   df <- as.data.frame(x)
   if (!(numer %in% names(df))) {
@@ -104,7 +98,6 @@ calc_eql <- function(x, numer = "i.num", denom = "num",
   # Truncate vector and calculate difference
   tprev <- tail(prev, nsteps)
   diff <- abs(max(tprev) - min(tprev))
-
   if (invisible == FALSE) {
     cat("Equilibrium Results")
     cat("\n=================================")
@@ -115,7 +108,6 @@ calc_eql <- function(x, numer = "i.num", denom = "num",
     cat("\nRel. Diff.:   ", round(diff, digits))
     cat("\n<= Threshold: ", diff <= threshold)
   }
-
   on.exit(options(scipen = old.scipen))
   out <- list(strprev = round(head(tprev, 1), digits),
               endprev = round(tail(tprev, 1), digits),
@@ -124,7 +116,6 @@ calc_eql <- function(x, numer = "i.num", denom = "num",
               reldiff = round(diff, digits),
               thresh = diff <= threshold)
   invisible(out)
-
 }
 
 
@@ -167,28 +158,21 @@ calc_eql <- function(x, numer = "i.num", denom = "num",
 #'
 check_bip_degdist <- function(num.m1, num.m2,
                               deg.dist.m1, deg.dist.m2) {
-
   deg.counts.m1 <- deg.dist.m1 * num.m1
   deg.counts.m2 <- deg.dist.m2 * num.m2
-
   tot.deg.m1 <- sum(deg.counts.m1 * (1:length(deg.dist.m1) - 1))
   tot.deg.m2 <- sum(deg.counts.m2 * (1:length(deg.dist.m2) - 1))
-
   mat <- matrix(c(deg.dist.m1, deg.counts.m1,
                   deg.dist.m2, deg.counts.m2), ncol = 4)
   mat <- rbind(mat, c(sum(deg.dist.m1), tot.deg.m1, sum(deg.dist.m2), tot.deg.m2))
-
   colnames(mat) <- c("m1.dist", "m1.cnt", "m2.dist", "m2.cnt")
   rownames(mat) <- c(paste0("Deg", 0:(length(deg.dist.m1) - 1)), "Edges")
-
   cat("Bipartite Degree Distribution Check\n")
   cat("=============================================\n")
   print(mat, print.gap = 3)
   cat("=============================================\n")
-
   reldiff <- (tot.deg.m1 - tot.deg.m2) / tot.deg.m2
   absdiff <- abs(tot.deg.m1 - tot.deg.m2)
-
   if (sum(deg.dist.m1) <= 0.999 | sum(deg.dist.m1) >= 1.001 |
       sum(deg.dist.m2) <= 0.999 | sum(deg.dist.m2) >= 1.001 | absdiff > 1) {
     if (sum(deg.dist.m1) <= 0.999 | sum(deg.dist.m1) >= 1.001) {
@@ -197,7 +181,6 @@ check_bip_degdist <- function(num.m1, num.m2,
     if (sum(deg.dist.m2) <= 0.999 | sum(deg.dist.m2) >= 1.001) {
       cat("** deg.dist.m2 TOTAL != 1 \n")
     }
-
     if (absdiff > 1) {
       if (tot.deg.m1 > tot.deg.m2) {
         msg <- "Mode 1 Edges > Mode 2 Edges:"
@@ -259,7 +242,6 @@ check_bip_degdist <- function(num.m1, num.m2,
 color_tea <- function(nd, old.var = "testatus", old.sus = "s", old.inf = "i",
                       old.rec = "r", new.var = "ndtvcol", new.sus, new.inf,
                       new.rec, verbose = TRUE) {
-
   if (missing(new.inf)) {
     new.inf <- transco("firebrick", 0.75)
   }
@@ -269,28 +251,22 @@ color_tea <- function(nd, old.var = "testatus", old.sus = "s", old.inf = "i",
   if (missing(new.rec)) {
     new.rec <- transco("seagreen", 0.75)
   }
-
   times <- 1:max(get.change.times(nd))
-
   for (at in times) {
-
     stat <- get.vertex.attribute.active(nd, old.var, at = at)
     infected <- which(stat == old.inf)
     uninfected <- which(stat == old.sus)
     recovered <- which(stat == old.rec)
-
     nd <- activate.vertex.attribute(nd, prefix = new.var, value = new.inf,
-                              onset = at, terminus = Inf, v = infected)
+                                    onset = at, terminus = Inf, v = infected)
     nd <- activate.vertex.attribute(nd, prefix = new.var, value = new.sus,
-                              onset = at, terminus = Inf, v = uninfected)
+                                    onset = at, terminus = Inf, v = uninfected)
     nd <- activate.vertex.attribute(nd, prefix = new.var, value = new.rec,
-                              onset = at, terminus = Inf, v = recovered)
-
+                                    onset = at, terminus = Inf, v = recovered)
     if (verbose == TRUE) {
       cat("\n", at, "/", max(times), "\t", sep = "")
     }
   }
-
   return(nd)
 }
 
@@ -303,18 +279,16 @@ color_tea <- function(nd, old.var = "testatus", old.sus = "s", old.inf = "i",
 #' @param dat Master data object passed through \code{netsim} simulations.
 #' @param at Current time step.
 #' @param fterms Vector of attributes used in formation formula, usually as
-#'        output of \code{\link{get_formula_terms}}.
+#'        output of \code{\link{get_formula_term_attr}}.
 #'
-#' @seealso \code{\link{get_formula_terms}}, \code{\link{get_attr_prop}},
+#' @seealso \code{\link{get_formula_term_attr}}, \code{\link{get_attr_prop}},
 #'          \code{\link{update_nwattr}}.
 #' @keywords netUtils internal
 #' @export
 #'
 copy_toall_attr <- function(dat, at, fterms) {
-
   otha <- names(dat$nw$val[[1]])
   otha <- otha[which(otha %in% fterms)]
-
   if (length(otha) > 0) {
     for (i in seq_along(otha)) {
       va <- get.vertex.attribute(dat$nw, otha[i])
@@ -326,7 +300,6 @@ copy_toall_attr <- function(dat, at, fterms) {
       }
     }
   }
-
   return(dat)
 }
 
@@ -341,7 +314,7 @@ copy_toall_attr <- function(dat, at, fterms) {
 #'        (see \code{\link{netest}}). See below for list of supported dissolution
 #'        models.
 #' @param duration A vector of mean edge durations in arbitrary time units.
-#' @param d.rate Death or exit rate from the population, as a single homogenous
+#' @param d.rate Departure or exit rate from the population, as a single homogenous
 #'        rate that applies to the entire population.
 #'
 #' @details
@@ -351,9 +324,9 @@ copy_toall_attr <- function(dat, at, fterms) {
 #'  \item \strong{Transformation:} the mean duration of edges in a network are
 #'        mathematically transformed to logit coefficients.
 #'  \item \strong{Adjustment:} in a dynamic network simulation in an open
-#'        population (in which there are deaths), it is further necessary to
+#'        population (in which there are departures), it is further necessary to
 #'        adjust these coefficients for dynamic simulations; this upward adjustment
-#'        accounts for death as a competing risk to edge dissolution.
+#'        accounts for departure as a competing risk to edge dissolution.
 #' }
 #'
 #' The current dissolution models supported by this function and in network
@@ -386,8 +359,8 @@ copy_toall_attr <- function(dat, at, fterms) {
 #'  \item \strong{coef.crude:} mean durations transformed into logit
 #'        coefficients.
 #'  \item \strong{coef.adj:} crude coefficients adjusted for the risk of
-#'        death on edge persistence, if the \code{d.rate} argument is supplied.
-#'  \item \strong{d.rate:} the death rate.
+#'        departure on edge persistence, if the \code{d.rate} argument is supplied.
+#'  \item \strong{d.rate:} the departure rate.
 #' }
 #'
 #' @seealso
@@ -399,31 +372,29 @@ copy_toall_attr <- function(dat, at, fterms) {
 #' @keywords netUtils
 #'
 #' @examples
-#' # Homogeneous dissolution model with no deaths
+#' # Homogeneous dissolution model with no departures
 #' dissolution_coefs(dissolution = ~offset(edges), duration = 25)
 #'
-#' # Homogeneous dissolution model with deaths
+#' # Homogeneous dissolution model with departures
 #' dissolution_coefs(dissolution = ~offset(edges), duration = 25,
 #'                   d.rate = 0.001)
 #'
 #' # Heterogeneous dissolution model in which same-race edges have
-#' # shorter duration compared to mixed-race edges, with no deaths
+#' # shorter duration compared to mixed-race edges, with no departures
 #' dissolution_coefs(dissolution = ~offset(edges) + offset(nodematch("race")),
 #'                   duration = c(20, 10))
 #'
 #' # Heterogeneous dissolution model in which same-race edges have
-#' # shorter duration compared to mixed-race edges, with deaths
+#' # shorter duration compared to mixed-race edges, with departures
 #' dissolution_coefs(dissolution = ~offset(edges) + offset(nodematch("race")),
 #'                   duration = c(20, 10), d.rate = 0.001)
 #'
 #'
 dissolution_coefs <- function(dissolution, duration, d.rate = 0) {
-
   # Error check for duration < 1
   if (any(duration < 1)) {
     stop("All values in duration must be >= 1", call. = FALSE)
   }
-
   # Check form of dissolution formula
   form.length <- length(strsplit(as.character(dissolution)[2], "[+]")[[1]])
   t1.edges <- grepl("offset[(]edges",
@@ -439,21 +410,18 @@ dissolution_coefs <- function(dissolution, duration, d.rate = 0) {
       t2.term <- "nodemix"
     }
   }
-
   model.type <- NA
   if (form.length == 1 && t1.edges == TRUE) {
     model.type <- "homog"
   } else if (form.length == 2 && t1.edges == TRUE &&
-      t2.term %in% c("nodematch", "nodefactor", "nodemix")) {
+             t2.term %in% c("nodematch", "nodefactor", "nodemix")) {
     model.type <- "hetero"
   } else {
     model.type <- "invalid"
   }
-
   if (length(d.rate) > 1) {
     stop("Length of d.rate must be 1", call. = FALSE)
   }
-
   # Log transformation of duration to coefficent
   if (t1.edges == FALSE) {
     stop("Dissolution models must start with offset(edges)", call. = FALSE)
@@ -466,40 +434,38 @@ dissolution_coefs <- function(dissolution, duration, d.rate = 0) {
     pg <- (duration[1] - 1) / duration[1]
     ps2 <- (1 - d.rate) ^ 2
     coef.crude <- log(pg / (1 - pg))
-    if (sqrt(ps2) <= pg) {
-      stop("The competing risk of mortality is too high given the duration. Specify a lower d.rate",
-           call. = FALSE)
+    if (ps2 <= pg) {
+      d.rate_ <- round(1-sqrt(pg),5)
+      str <- paste("The competing risk of departure is too high for the given",
+                   " duration of ", duration[1], "; specify a d.rate lower than ",
+                   d.rate_,".",sep="")
+      stop(str, call. = FALSE)
     }
     coef.adj <- log(pg / (ps2 - pg))
   }
   if (form.length == 2) {
-   if (t2.term %in% c("nodematch", "nodefactor", "nodemix")) {
-
-     coef.crude <- coef.adj <- NA
-     for (i in 1:length(duration)) {
-
-       pg.thetaX <- (duration[i] - 1) / duration[i]
-       ps2.thetaX <- (1 - d.rate) ^ 2
-       if (sqrt(ps2.thetaX) <= pg.thetaX) {
-         stop("The competing risk of mortality is too high for the given the ",
-              "duration in place ", i, ". Specify a lower d.rate", call. = FALSE)
-       }
-       if (i == 1) {
-         coef.crude[i] <- log(pg.thetaX / (1 - pg.thetaX))
-         coef.adj[i] <- log(pg.thetaX / (ps2.thetaX - pg.thetaX))
-       } else {
-         coef.crude[i] <- log(pg.thetaX / (1 - pg.thetaX)) - coef.crude[1]
-         coef.adj[i] <- log(pg.thetaX / (ps2.thetaX - pg.thetaX)) - coef.adj[1]
-       }
-
-     }
-
-   } else {
-     stop("Supported heterogeneous dissolution model terms are nodematch, ",
-          "nodefactor, or nodemix", call. = FALSE)
-   }
+    if (t2.term %in% c("nodematch", "nodefactor", "nodemix")) {
+      coef.crude <- coef.adj <- NA
+      for (i in 1:length(duration)) {
+        pg.thetaX <- (duration[i] - 1) / duration[i]
+        ps2.thetaX <- (1 - d.rate) ^ 2
+        if (sqrt(ps2.thetaX) <= pg.thetaX) {
+          stop("The competing risk of departure is too high for the given the ",
+               "duration in place ", i, ". Specify a lower d.rate", call. = FALSE)
+        }
+        if (i == 1) {
+          coef.crude[i] <- log(pg.thetaX / (1 - pg.thetaX))
+          coef.adj[i] <- log(pg.thetaX / (ps2.thetaX - pg.thetaX))
+        } else {
+          coef.crude[i] <- log(pg.thetaX / (1 - pg.thetaX)) - coef.crude[1]
+          coef.adj[i] <- log(pg.thetaX / (ps2.thetaX - pg.thetaX)) - coef.adj[1]
+        }
+      }
+    } else {
+      stop("Supported heterogeneous dissolution model terms are nodematch, ",
+           "nodefactor, or nodemix", call. = FALSE)
+    }
   }
-
   out <- list()
   out$dissolution <- dissolution
   out$duration <- duration
@@ -507,7 +473,6 @@ dissolution_coefs <- function(dissolution, duration, d.rate = 0) {
   out$coef.adj <- coef.adj
   out$d.rate <- d.rate
   out$model.type <- model.type
-
   class(out) <- "disscoef"
   return(out)
 }
@@ -544,41 +509,35 @@ dissolution_coefs <- function(dissolution, duration, d.rate = 0) {
 #' est <- netest(nw, formation, target.stats, coef.diss, verbose = FALSE)
 #'
 #' # Simulate the network and extract a timed edgelist
-#' sim <- netdx(est, nsims = 1, nsteps = 100, verbose = FALSE)
-#' el <- sim$edgelist[[1]]
+#' dx <- netdx(est, nsims = 1, nsteps = 100, keep.tedgelist = TRUE, verbose = FALSE)
+#' el <- as.data.frame(dx)
 #'
 #' # Calculate censoring
 #' edgelist_censor(el)
 #'
 edgelist_censor <- function(el) {
-
   # left censored
   leftcens <- el$onset.censored
   leftcens.num <- sum(leftcens)
   leftcens.pct <- leftcens.num / nrow(el)
-
   # right censored
   rightcens <- el$terminus.censored
   rightcens.num <- sum(rightcens)
   rightcens.pct <- rightcens.num / nrow(el)
-
   # partnership lasts for entire window (left and right censored)
   lrcens <- el$onset.censored & el$terminus.censored
   lrcens.num <- sum(lrcens)
   lrcens.pct <- lrcens.num / nrow(el)
-
   # fully observed
   nocens <- el$onset.censored == FALSE & el$terminus.censored == FALSE
   nocens.num <- sum(nocens)
   nocens.pct <- nocens.num / nrow(el)
-
   ## Table
   nums <- rbind(leftcens.num, rightcens.num, lrcens.num, nocens.num)
   pcts <- rbind(leftcens.pct, rightcens.pct, lrcens.pct, nocens.pct)
   out <- cbind(nums, pcts)
   rownames(out) <- c("Left Cens.", "Right Cens.", "Both Cens.", "No Cens.")
   colnames(out) <- c("num", "pct")
-
   return(out)
 }
 
@@ -617,38 +576,34 @@ edgelist_censor <- function(el) {
 #' est <- netest(nw, formation, target.stats, coef.diss, verbose = FALSE)
 #'
 #' # Simulate the network and extract a timed edgelist
-#' sim <- netdx(est, nsims = 1, nsteps = 100, verbose = FALSE)
-#' el <- sim$edgelist[[1]]
+#' dx <- netdx(est, nsims = 1, nsteps = 100, keep.tedgelist = TRUE, verbose = FALSE)
+#' el <- as.data.frame(dx)
 #'
 #' # Calculate ages directly from edgelist
-#' ( ma <- edgelist_meanage(el = el) )
+#' mean_ages <- edgelist_meanage(el = el)
+#' mean_ages
 #'
 #' # Alternatively, netdx calculates these
-#' sim$pages
-#' identical(sim$pages[[1]], ma)
+#' dx$pages
+#' identical(dx$pages[[1]], mean_ages)
 #'
 edgelist_meanage <- function(x, el) {
-
   # If passing a netest object directly
   if (!(missing(x))) {
     el <- x$edgelist
   }
-
   terminus <- el$terminus
   onset <- el$onset
   minterm <- min(terminus)
   maxterm <- max(terminus)
-
   meanpage <- rep(NA, maxterm)
   for (at in minterm:maxterm) {
     actp <- (onset <= at & terminus > at) |
-            (onset == at & terminus == at);
+      (onset == at & terminus == at);
     page <- at - onset[actp] + 1
     meanpage[at] <- mean(page)
   }
-
   meanpage <- meanpage[1:(length(meanpage) - 1)]
-
   return(meanpage)
 }
 
@@ -662,66 +617,64 @@ edgelist_meanage <- function(x, el) {
 #' @param nw The \code{networkDynamic} object contained in the \code{netsim}
 #'        simulation.
 #' @param fterms Vector of attributes used in formation formula, usually as
-#'        output of \code{\link{get_formula_terms}}.
+#'        output of \code{\link{get_formula_term_attr}}.
 #' @param only.formula Limit the tables to those terms only in \code{fterms},
 #'        otherwise output proportions for all attributes on the network object.
 #'
-#' @seealso \code{\link{get_formula_terms}}, \code{\link{copy_toall_attr}},
+#' @seealso \code{\link{get_formula_term_attr}}, \code{\link{copy_toall_attr}},
 #'          \code{\link{update_nwattr}}.
 #' @keywords netUtils internal
 #' @export
 #'
 get_attr_prop <- function(nw, fterms, only.formula = TRUE) {
-
   if (is.null(fterms)) {
     return(NULL)
   }
-
   nwVal <- names(nw$val[[1]])
   if (only.formula == TRUE) {
     nwVal <- nwVal[which(nwVal %in% fterms)]
   }
-
   out <- list()
   for (i in 1:length(nwVal)) {
     tab <- prop.table(table(nw %v% nwVal[i]))
     out[[i]] <- tab
   }
   names(out) <- nwVal
-
   return(out)
 }
 
 
-#' @title Outputs Formula Terms into a Character Vector
+#' @title Outputs ERGM Formula Attributes into a Character Vector
 #'
 #' @description Given a formation formula for a network model, outputs it into
-#'              a character vector of terms to be used in \code{netsim}
+#'              a character vector of vertex attributes to be used in \code{netsim}
 #'              simulations.
 #'
-#' @param formula Right-hand sided formation formula.
+#' @param form an ergm model formula
+#' @param nw a network object
 #'
-#' @seealso \code{\link{copy_toall_attr}}, \code{\link{get_attr_prop}},
-#'          \code{\link{update_nwattr}}.
-#' @keywords netUtils internal
 #' @export
 #'
-get_formula_terms <- function(formula) {
+get_formula_term_attr <- function(form, nw) {
 
-  fterms <- attributes(terms.formula(formula))$term.labels
-  fterms <- strsplit(fterms, split = "[\"]")
-  tl <- sapply(fterms, length)
-  if (all(tl == 1)) {
-    fterms <- NULL
+  nw_attr <- names(nw$val[[1]])
+  nw_attr <- setdiff(nw_attr, c("active", "vertex.names", "na"))
+
+  if (length(nw_attr) == 0) {
+    return(NULL)
+  }
+  matches <- sapply(nw_attr, function(x) grepl(x, form))
+  matches <- colSums(matches)
+
+  out <- names(matches)[which(matches == 1)]
+  if (length(out) == 0) {
+    return(NULL)
   } else {
-    fterms <- fterms[tl > 1]
-    fterms <- unique(sapply(fterms, function(x) x[2]))
+    return(out)
   }
 
-  return(fterms)
 }
 
-
 #' @title Mode Numbers for Bipartite Network
 #'
 #' @description Outputs mode numbers give ID numbers for a bipartite network.
@@ -741,17 +694,13 @@ get_formula_terms <- function(formula) {
 #' idmode(nw, ids = c(3, 6))
 #'
 idmode <- function(nw, ids) {
-
   n <- network.size(nw)
-
   if (missing(ids)) {
     ids <- seq_len(n)
   }
-
   if (any(ids > n)) {
     stop("Specify ids between 1 and ", n)
   }
-
   if (!is.bipartite(nw)) {
     out <- rep(1, n)
   } else {
@@ -760,7 +709,6 @@ idmode <- function(nw, ids) {
                rep(2, n - m1size))
     out <- modes[ids]
   }
-
   return(out)
 }
 
@@ -782,24 +730,20 @@ idmode <- function(nw, ids) {
 #' modeids(nw, mode = 2)
 #'
 modeids <- function(nw, mode) {
-
   if (!is.numeric(nw$gal$bipartite)) {
     stop("nw must be a bipartite network")
   }
   if (missing(mode)) {
     stop("Specify mode=1 or mode=2")
   }
-
   n <- network.size(nw)
   m1size <- nw$gal$bipartite
-
   if (mode == 1) {
     out <- 1:m1size
   }
   if (mode == 2) {
     out <- (m1size + 1):n
   }
-
   return(out)
 }
 
@@ -807,7 +751,7 @@ modeids <- function(nw, mode) {
 #' @title Update Attribute Values for a Bipartite Network
 #'
 #' @description Adds new values for attributes in a bipartite network in which
-#'              there may be births/entries in the first mode, which requires
+#'              there may be arrivals/entries in the first mode, which requires
 #'              splitting the attribute vector into two, adding the new values,
 #'              and re-concatenating the two updated vectors.
 #'
@@ -816,24 +760,19 @@ modeids <- function(nw, mode) {
 #' @param val Fixed value to set for all incoming nodes.
 #' @param nCurrM1 Number currently in mode 1.
 #' @param nCurrM2 Number currently in mode 2.
-#' @param nBirths Number of births/entries in mode 1.
-#' @param nBirthsM2 Number of births/entries in mode 2.
+#' @param narrivals Number of arrivals/entries in mode 1.
+#' @param narrivalsM2 Number of arrivals/entries in mode 2.
 #'
 #' @export
 #' @keywords netUtils internal
 #'
-split_bip <- function(dat, var, val, nCurrM1, nCurrM2, nBirths, nBirthsM2) {
-
+split_bip <- function(dat, var, val, nCurrM1, nCurrM2, nArrivals, nArrivalsM2) {
   oldVarM1 <- dat$attr[[var]][1:nCurrM1]
   oldVarM2 <- dat$attr[[var]][(nCurrM1 + 1):(nCurrM1 + nCurrM2)]
-
-  newVarM1 <- c(oldVarM1, rep(val, nBirths))
-  newVarM2 <- c(oldVarM2, rep(val, nBirthsM2))
-
+  newVarM1 <- c(oldVarM1, rep(val, nArrivals))
+  newVarM2 <- c(oldVarM2, rep(val, nArrivalsM2))
   newVar <- c(newVarM1, newVarM2)
-
   dat$attr[[var]] <- newVar
-
   return(dat)
 }
 
@@ -859,7 +798,6 @@ split_bip <- function(dat, var, val, nCurrM1, nCurrM2, nBirths, nBirthsM2) {
 #' @export
 #'
 update_nwattr <- function(nw, newNodes, rules, curr.tab, t1.tab) {
-
   for (i in 1:length(curr.tab)) {
     vname <- names(curr.tab)[i]
     rule <- rules[[vname]]
@@ -898,7 +836,6 @@ update_nwattr <- function(nw, newNodes, rules, curr.tab, t1.tab) {
     nw <- set.vertex.attribute(nw, attrname = vname,
                                value = nattr, v = newNodes)
   }
-
   return(nw)
 }
 
@@ -944,7 +881,7 @@ update_nwattr <- function(nw, newNodes, rules, curr.tab, t1.tab) {
 #' deg.el <- get_degree(el)
 #' deg.el
 #'
-#' identical(ergm.method, deg.net, deg.el)
+#' identical(as.integer(ergm.method), deg.net, deg.el)
 #'
 get_degree <- function(x) {
   if (inherits(x, "network")) {
@@ -958,6 +895,7 @@ get_degree <- function(x) {
   return(out)
 }
 
+
 #' @title Truncate Simulation Time Series
 #'
 #' @description Left-truncates a simulation epidemiological summary statistics and
@@ -975,12 +913,11 @@ get_degree <- function(x) {
 #' @export
 #'
 #' @examples
-#' set.seed(12345)
 #' param <- param.icm(inf.prob = 0.2, act.rate = 0.25)
 #' init <- init.icm(s.num = 500, i.num = 1)
 #' control <- control.icm(type = "SI", nsteps = 200, nsims = 1)
 #' mod1 <- icm(param, init, control)
-#' df <- as.data.frame(mod1, out = "vals")
+#' df <- as.data.frame(mod1)
 #' print(df)
 #' plot(mod1)
 #' mod1$control$nsteps
@@ -992,21 +929,15 @@ get_degree <- function(x) {
 #' mod2$control$nsteps
 #'
 truncate_sim <- function(x, at) {
-
   if (class(x) != "icm" && class(x) != "netsim") {
     stop("x must be either an object of class icm or class netsim",
          call. = FALSE)
   }
-
   rows <- at:(x$control$nsteps)
-
   # epi
   x$epi <- lapply(x$epi, function(r) r[rows, ])
-
   # control settings
   x$control$start <- 1
   x$control$nsteps <- max(seq_along(rows))
-
   return(x)
 }
-
